@@ -1,4 +1,4 @@
 library(testthat)
 library(alluvial)
 
-test_package("alluvial")
+test_check("alluvial")
